# ***WaterpyBal***

This repository contains an open source Python library for water balance modelling.

---



## ***Package information:***
\
Name: WaterpyBal

version: 1.0.0

Author: Ashkan Hassanzadeh   

Email: ashkan.hassanzadeh@gmail.com

python: 3.*

License: agpl-3.0

---



## ***Installation:***
\
pip can be used for the installation:

`pip install waterpybal`

Alternatively, download the waterpybal folder from the github repository and add it to lib folder in python path alongside other python libraries.


---



## ***Jupyter Notebook:***
\
There is a notebook in [WaterpyBal's github repository](https://github.com/IDAEA-EVS/waterpybal) that explains an example of implementing WaterpyBal on spatial and isotopic data


---


## ***WaterpyBal Studio: Graphic User interface of WaterpyBal***

The GUI of WaterpyBal (WaterpyBal Studio), alongside the installation guide and the user manual can be found [here](http://hdl.handle.net/10261/305226)